﻿/////////////////////////////////////////
// Program:
// resultwin.js
// Description:
// インデックス検索を行って検索結果をサブウィンドウに表示する
// Date: 2008/05/16
// Author: Atsutoshi Murata
// Update:
// 1.0.1 2008/05/13 Mac10.0.4 Safari2.0対応。
// 1.1.1 2008/05/16 ダブルクオートで区切られた単語は１つの検索語と扱う様に修正。
// 1.1.2 2008/05/16 OR検索の不具合を修正。
// 1.1.3 2008/05/19 キーワードは長い順番に色分けを行う
// 1.1.4 2008/05/19 引用文の長さは、前25文字＋検索文字+後35文字に変更
// 1.1.5 2008/05/19 引用文が先頭から始まっていない場合には、...をつける
// 1.1.6 2008/05/19 タイトル名にカテゴリ名を表示する
// 1.1.7 2008/05/19 ダブルクオートで区切られた半角スペースのない文字列"コピー"が検索できなかった不具合を修正
// 1.1.8 2008/05/19　全角の＆を入力しても実体参照文字に変換されないバグを修正
// 1.1.9 2008/05/20 検索結果を実体参照文字に変換して表示。HTML実体参照文字への変換。小文字への変換のアルゴリズムの見直し。
// 1.1.10 2008/05/20 検索でヒットしなかった文字列をメッセージとして表示する。
// 1.1.11 2008/05/20 検索語がキーワードに全てある場合で、検索結果が０の場合のメッセージ処理を追加
// 1.1.12 2008/05/20 ダブルクオートて区切るため、ダブルクオートをHTMLの実体参照に変換しないように修正
// 1.1.13 2008/05/20 検索結果でヒットしなかった検索語は、色分けしないように修正
// 1.1.14 2008/05/20 プログラムを見直し、可能なかぎり無駄な処理を整理しました。
// 1.1.15 2008/05/21 ダブルクオートで区切った検索ができるように変更しました。1.1.12の訂正。
// 1.1.16 2008/05/23 コロンの全角(：)を半角(:)に直す部分を半角(,)にしていました。修正しました。
// 1.1.17 2008/05/23 Mac 10.0.4 Safari2.0でサブウィンドウが読み込み中になって表示が更新されないので、ウィンドウを閉じる様に変更
// 1.1.18 2008/05/26 サブウィンドウの引用文表示がまれに表示されない不具合を解消するために、画面を一定時間後に再表示する仕組みを追加
// 1.1.19 2008/05/26 JSONファイルとkeyword.txtのHTML実体参照は通常文字にしてから、引用文のHTML実体参照への変換はHTML表示直前に行う。
// 1.1.20 2008/05/26 引用文の色分けは一色にする。
// 1.1.21 2008/05/26 AND検索フラグを追加。
// 1.1.22 2008/05/27 Safari対策追加。「サブウィンドウを開く->インデックスを数回クリック->末端コンテンツのリンクをクリック->検索語を変えて検索」した時に読み込み中となる不具合の解消
// 1.1.23 2008/05/27 検索語のテキストボックスに文字列がない場合に、何もしないように変更。
// 1.1.24 2008/05/27 テキストボックスに入力された検索語をHTML実体参照に変換しないように修正。
// 1.1.25 2008/05/27 引用文の文字列を置き換える際の不具合を修正。小文字化された引用文と小文字化された検索語を比較して、その結果を元の引用文で置き換える様に修正。
// 1.1.26 2008/05/27 ＜＞”全角スペース＝が大文字->小文字に変換するキャラクタリストに抜けていた。
// 1.1.27 2008/05/27 実体参照文字をテキストボックスに入力した時は、ヒットしないが、検索結果のサブウィンドウには、実体参照文字として表示するように修正。
// 1.1.28 2008/06/04 ダイナミックロードで失敗した引用文を追加読み込みを行う様に修正
// 1.1.29 2008/06/04 検索語のハイライトと実体参照文字への変換関数を更新。
// 1.1.30 2008/06/04 ベンチマークした時間をタイトルバーに表示
// 1.1.31 2008/06/04 Safari2.0対応。Safariの場合には、毎回ページはリロードされる
// 1.1.32 2008/06/05 ローカライズ対応。日本語の文字列は、result.htmlの変数を使用する
// 1.1.33 2008/06/05 リロードが発生した引用文のみをロードするように変更。リロードの回数は10回までに制限。
// 1.1.34 2008/06/06 &(半角)を入力した時に検索用のテキストボックスに&amp;となってしまうため、オリジナルの文字列を保持する変数を作成。
// 1.1.35 2008/06/06 Safari2.0で動作するように、ConvertToLowerを修正。
// 1.1.36 2008/06/09 全角を半角に変換する正規表現配列を作成して、メモリを消費しないように変更した。
// 1.1.37 2008/06/17 サブウィンドウでの検索キーワードの表示で実体参照変換の不具合を修正した。
// 1.1.38 2008/06/17 result.htmlが、charupper2lower.jsファイルを参照するように変更。
// 1.1.39 2008/06/19 引用文が文頭と文末以外のみ...を表示するように修正。
// 1.1.40 2008/06/23 タイトル文字をHTML実体参照に変換していなかった不具合を修正。
// 1.1.41 2008/06/23 引用分を表示しないオプションを追加。
// 1.1.42 2008/07/23 新検索の検索結果の表示を旧検索と合わせた。
var strFileUpdate = "1.1.42";
/////////////////////////////////////////
// 検索した結果をプロパティで格納するオブジェクト
//document.body.style.cursor="wait";
var startTime = new Date();
resultDoc = new Object();
/////////////////////////////////////////
// 検索語のグローバル変数
/////////////////////////////////////////
resultDoc.bQuote = true;	// 引用文を表示する場合には、true
resultDoc.bDebug = false;		// デバッグ用のオプション表示
resultDoc.prePos = 25; 			// 検索語の前の引用文の文字数
resultDoc.postPos = 35;			// 検索語の後の引用文の文字数
/////////////////////////////////////////
resultDoc.strOrgInputText = "";
resultDoc.strInputText = "";
resultDoc.searchWord = new Array();
resultDoc.searchWordOrg= new Array();// 2008/06/17　A.Murata 新規作成
resultDoc.wordSearchResult = new Array();
resultDoc.nMaxSearchWord = 0;		//検索語の数
resultDoc.nHitCount = 0;			// 検索のヒット数
resultDoc.loadFlag = new Array();	// 引用文のリロードを行うためのフラグ
resultDoc.nStartNumber = 0;
resultDoc.contentIndexArray = new Array();
resultDoc.nSafari = SafariCheck();
resultDoc.nRetryCount = 0;			//ダイナミックロードのリトライ回数のカウント変数
resultDoc.nMaxRetryCount = 20;		//ダイナミックロードのリトライ回数の最大カウント
/////////////////////////////////////////
// インデックスリンク表示制御のためのオブジェクト
var IndexLink = new Object();
IndexLink.nMaxIndecies = 0;// 最大リンクインデックス番号
IndexLink.nStartIndex = 0;//リンクインデックススの開始番号
IndexLink.nCurrIndex = 0;// 現在選択されているリンクインデックス番号
IndexLink.nResultPerPage = 10;// 最大表示数

window.onload = function()
{
	// 文例を表示するイベント
	document.getElementById("showResultButton").onclick = function()
	{
		//alert( "showResultButton()" );
 		var i = 1;
  		
	    for( j = resultDoc.nStartNumber; i <= IndexLink.nResultPerPage && j < resultDoc.nHitCount; ++j, ++i )
	    {
	        var strFolder = contentArray[resultDoc.contentIndexArray[j]];
	        var strFolder_no_Hyphen = strFolder.replace( /-/, "_" );
	        // カテゴリ名を表示するように変更
	        // 2008/05/19　A.Murata 新規作成
	        var strCategory = ( resultDoc[strFolder_no_Hyphen+"_category"] )? resultDoc[strFolder_no_Hyphen+"_category"]  : "";
	        var strLink = ( resultDoc[strFolder_no_Hyphen+"_title"] )? resultDoc[strFolder_no_Hyphen+"_title"]  : "";
	        
	        // リンク名もHTMLの実体参照文字に変換する
	        // 2008/06/23　A.Murata 新規作成
	        strLink = ToHtmlEntityChar(strLink);
	        
			var strSearchResult = "SearchResult"+i;

	        var strContent = "";
	        var strContentLower = "";
	        //var searchWordOrg = new Array();
	        var nSearchWordOrg = 0;

	        for( var k = 0; k < resultDoc.nMaxSearchWord; ++k )
	        {
	        	// 検索した結果がないのならスキップ
	        	if( resultDoc.wordSearchResult[k] == false )
		        {
		        	continue;
		        }

	        	// プロパティから
	        	if( resultDoc[strFolder_no_Hyphen] )
	        	{
	        		// 例文の文章も一旦小文字化して比較
	        		var lowerContent = ConvertToLower( resultDoc[strFolder_no_Hyphen] );
	        		// キーワードが最初に出現する位置を求める
	        		var pos = lowerContent.indexOf( resultDoc.searchWord[k] );
	        		
					if( pos >= 0 )
					{
						// 出現した位置から、前後の文章を切り出す
						var startPos = pos - resultDoc.prePos;
						
						// 引用文の長さは、前25文字＋検索文字+後35文字に変更
						// 2008/05/19　A.Murata 変更
						var endPos = pos + resultDoc.searchWord[k].length + resultDoc.postPos;
						//if( endPos >= lowerContent.length )
						//{
						//	endPos = lowerContent.length-1;
						//}
						
						if( startPos > 0 )
						{
							strContent += "...";
							strContentLower += "...";
						}

			        	strContent += resultDoc[strFolder_no_Hyphen].substring( startPos, endPos );
			        	strContentLower += lowerContent.substring( startPos, endPos );

				    	if( endPos < lowerContent.length )
				    	{
							strContent += "...";
							strContentLower += "...";
				    	}
					}
				}
			}
			
			if( strContent )
			{
				//　テキストに色付けをして、実体参照文字へ変換する
				// 2008/06/04　A.Murata 新規作成
				strContent =  highlightText(strContent, strContentLower, resultDoc.searchWord) + "<br/>";
			}
			
			var strTitle =  (j+1) + ": " + strCategory;
			if( resultDoc.bDebug )
			{
				 strTitle +=( " " + strFolder + " " + strFolder_no_Hyphen);
			}
			
  			printResult( strSearchResult, strTitle, strFolder, strLink, strContent );
  			
  			if( resultDoc.bDebug )
  			{
	  			// ベンチマーク追加
	  			// 2008/06/04　A.Murata 新規作成
	  			// 2008/06/04　A.Murata デバック
			    var endTime = new Date();
				var resultTime = new Date( endTime - startTime );
				var min = resultTime.getMinutes();
				var sec = resultTime.getSeconds();
				var msec = resultTime % 1000;
				document.title = "計算時間　: " + min + ":" + sec + "." + msec + " リトライ回数:"+ resultDoc.nRetryCount;
			}
		}
	    
	    var nReloadCount = 0;
	    // ここでもし読み込まれていない引用文があるのなら、もう一度ダイナミックロードを行う
	    // 2008/06/04　A.Murata 新規作成
   	    for( var k = 1, j = resultDoc.nStartNumber; k <= IndexLink.nResultPerPage && j < resultDoc.nHitCount; ++j, ++k )
	    {
	    	// <dd id="ddSearchResult番号">タグの中身を調べる
			var strSearchResult = "ddSearchResult"+k;
	   		var str =  document.getElementById( strSearchResult ).innerHTML;
	   		if( str.length <= 0 )
	   		{
	   			++nReloadCount;
	   		}
	   		else
	   		{
	   			resultDoc.loadFlag[k-1] = 0;
	   		}
	   	}

 	    // もし10件に満たない場合には、残りをクリアする
	    for( ; i <= IndexLink.nResultPerPage; ++i )
	    {
   			var strSearchResult = "SearchResult"+i;
			document.getElementById( strSearchResult ).innerHTML = "";
	    }

		// リロード回数がある場合で、且つリトライ回数が10回未満なら、再度ダイナミックロードを行う
	   	if( nReloadCount > 0 && resultDoc.nRetryCount < resultDoc.nMaxRetryCount )
	   	{
  			document.getElementById("dynamicLoadButton").onclick();
  			++resultDoc.nRetryCount;
	   	}
	}

	// ダイナミックロード
	document.getElementById("dynamicLoadButton").onclick = function()
	{
	    // １０件分追加する
	    for( var i = 1, j = resultDoc.nStartNumber; i <= IndexLink.nResultPerPage && j < resultDoc.nHitCount; ++i, ++j )
	    {
	    	// １の時だけロード
	    	if( resultDoc.loadFlag[i-1] )
	    	{
		        var strFolder = contentArray[resultDoc.contentIndexArray[j]];
		        loadJSONfile( "../contents/" + strFolder + "/func.js" )
	    	}
	    }
       	// 遅延読み込みをする
		setTimeout( 'document.getElementById("showResultButton").onclick()', 300 );	
	}

	// インデックスサーチ関数
	document.getElementById("searchButton").onclick = function()
	{
		// テキストボックスの文字列の長さがない時は何もしない
		if(  window.opener.document.searchform.word.value.length <= 0 )
		{
		  	document.getElementById("result_brief").innerHTML = keywordLabel+": &quot;&quot;<br/>("+countLabel+ ": 0 )<br/>";
			return;
		}
			
		//alert( "searchButton()" );
		resultDoc.nHitCount = searchOperation();
		// 2008/06/17　A.Murata 修正
  		var strResult = ToHtmlEntityChar(resultDoc.strInputText);
		// 結果表示
		// 2008/06/04　A.Murata デバック
	   	var strBrief = "";
	   	if( resultDoc.bDebug )
	   	{
	   		strBrief += "バージョン<font color='red'>" + strFileUpdate + "</font><br/>" ;
	   	}
	   	
	   	strBrief += (keywordLabel + ": &quot;" + strResult + "&quot;<br/>(" + countLabel+ ": " + resultDoc.nHitCount + " )<br/>");

	  	document.getElementById("result_brief").innerHTML = strBrief;

	    // 何も見つからなかったか、全て見つかった場合には何もしない。
	    if( resultDoc.nHitCount == 0 )
	    {
	    	clearResult();
	        return;
	    }

	   	// メッセージエリアへの文字列の出力
    	IndexLink.nMaxIndecies = parseInt(resultDoc.nHitCount/IndexLink.nResultPerPage);

		// 余りがある場合には１を加算する
		if( (resultDoc.nHitCount - IndexLink.nResultPerPage*IndexLink.nMaxIndecies) > 0 )
		{
			IndexLink.nMaxIndecies += 1;
		}
	    // Safari対応
	    // 2008/06/04　A.Murata 新規作成
	    if( resultDoc.nSafari )
	    {
			printLinkIndicesSafari();
		}
		else
		{
			printLinkIndices();
		}
		
		// 2008/06/05　A.Murata 新規作成
		// 1ならロードする
		resetLoadFlag();
		
		document.getElementById("dynamicLoadButton").onclick();

	}
	
	document.getElementById("searchButton").onclick();
}
// 2008/06/05　A.Murata 新規作成
function resetLoadFlag()
{
	resultDoc.nRetryCount = 0;
	for( var i = 0; i < 10; ++i )
	{
		resultDoc.loadFlag[i] = 1;
	}
}
// 次へをクリックした時のイベントハンドラ
// 2008/05/26　A.Murata 変更
function nextLinkIndex()
{
	 setLinkIndex( IndexLink.nCurrIndex+1 );
}
// 前へをクリックした時のイベントハンドラ
// 2008/05/26　A.Murata 変更
function prevLinkIndex()
{
	 setLinkIndex( IndexLink.nCurrIndex-1 );
}
// インデックスの数字をクリックした時のイベントハンドラ
// 2008/05/26　A.Murata 新規作成
function clickLinkIndex( n )
{
	setLinkIndex( n );
}
function calcLinkIndex( n )
{
	IndexLink.nCurrIndex = n;

	if( IndexLink.nCurrIndex < 0 )
	{
		IndexLink.nCurrIndex = 0;
	}
	else if( IndexLink.nCurrIndex >= IndexLink.nMaxIndecies )
	{
		IndexLink.nCurrIndex = IndexLink.nMaxIndecies-1;
	}

	// もし10件以内なら、10件表示する
	if( IndexLink.nCurrIndex > (IndexLink.nMaxIndecies-IndexLink.nResultPerPage) )
	{
		IndexLink.nStartIndex = IndexLink.nMaxIndecies-IndexLink.nResultPerPage;
	}

	if( IndexLink.nCurrIndex < IndexLink.nResultPerPage )
	{
		IndexLink.nStartIndex = 0;
	}
	else
	{
		IndexLink.nStartIndex = IndexLink.nCurrIndex - (IndexLink.nResultPerPage/2);
	}
}
// ページ送りをする
function setLinkIndex( n )
{
	// ベンチマーク追加
	// 2008/06/04　A.Murata 新規作成
	 startTime = new Date();
	 // 2008/06/05　A.Murata 新規作成
	resetLoadFlag();

	calcLinkIndex( n );

	printLinkIndices();

	resultDoc.nStartNumber = IndexLink.nCurrIndex*IndexLink.nResultPerPage;
	document.getElementById("dynamicLoadButton").onclick();	
}
// Mac版のSafari対応
// アンカーリンクの#がサブウィンドウのURLの末尾についていると、
// サブウィンドウが読み込み中になる不具合がある。
// そのため、Safariでは、#を使わずに毎回ページをリロードして
// 引数で、ページ番号と選択されているページ番号を引数で渡して
// ページを表示する際に、引数の選択されているページ番号を表示する
// 様に修正をした。
// 2008/06/04　A.Murata 新規作成
function printLinkIndicesSafari()
{
    // ここで引数にインデックスがあれば、それをセットする
    var strArgs = location.href.split("?");
	if( strArgs.length > 2 )
	{
		IndexLink.nStartIndex = parseInt(strArgs[1]);
		IndexLink.nCurrIndex = parseInt(strArgs[2]);	
		resultDoc.nStartNumber = IndexLink.nCurrIndex*IndexLink.nResultPerPage;
	}
	// リンクインデックス番号の再計算
	calcLinkIndex( IndexLink.nCurrIndex );
	// 再読み込みするページ名のセット
	var strResultHtml = "result.html";
	var i = IndexLink.nStartIndex;
	var strIndices = "";
	// インデックスリンクの作成(引数でページ番号をセットする。必ずリロードするので、クリックイベントは不要)

	// 前への場合
	if( IndexLink.nCurrIndex > 0 )
	{
		// ページがリロードされる時に、親ウィンドウの検索テキストボックスにもう一度検索語をセットする。
		// もし、別のメニューとかを操作した時に、検索テキストボックスが空になっていると、ページ送りができなくなるため。
		// 2008/06/05　A.Murata 新規作成
		strIndices += ("<a href='" + strResultHtml + "?"+ IndexLink.nStartIndex+ "?"+ (IndexLink.nCurrIndex-1) + "' onclick='form_value_feedback()'>" + prevLabel + "</a>  ");
	}

	for( var j = 0; j < IndexLink.nResultPerPage && i < IndexLink.nMaxIndecies; j++, i++ )
	{
		strIndices += ("<a href='" + strResultHtml + "?"+ IndexLink.nStartIndex+ "?"+ i + "' onclick='form_value_feedback()'>");
		// 現在のページ番号を強調表示する
		if( i == IndexLink.nCurrIndex )
		{
			strIndices += ( "<b>"+ (i+1)+ "</b></a>  ");
		}
		else
		{	
			strIndices += ( "<font size='-1'>"+ (i+1)+"</font></a>  ");
		}
	}

	// 後への場合
	if( IndexLink.nCurrIndex < (IndexLink.nMaxIndecies-1) )
	{
		strIndices += ("<a href='" + strResultHtml + "?"+ IndexLink.nStartIndex+ "?"+ (IndexLink.nCurrIndex+1) + "' onclick='form_value_feedback()'>"+ nextLabel + "</a>  ");
	}

	strIndices += "<BR/>";
	strIndices += "<BR/>";
	
	document.getElementById("indexText").innerHTML = strIndices;
}
function printLinkIndices()
{
	//alert( "printLinkIndices()" );
	var i = IndexLink.nStartIndex;
	var strIndices = "";

	if( IndexLink.nCurrIndex > 0 )
	{
		strIndices += ("<a href='#' onclick='prevLinkIndex()'>" + prevLabel + "</a>  ");
	}

	for( var j = 0; j < IndexLink.nResultPerPage && i < IndexLink.nMaxIndecies; j++, i++ )
	{
		strIndices += ("<a href='#' onclick='clickLinkIndex(" + i +");'>");
		if( i == IndexLink.nCurrIndex )
		{
			strIndices += ("<b>"+ (i+1)+ "</b></a>  ");
		}
		else
		{	
			strIndices += ( "<font size='-1'>"+ (i+1)+"</font></a>  ");
		}
	}

	if( IndexLink.nCurrIndex < (IndexLink.nMaxIndecies-1) )
	{
		strIndices += ("<a href='#' onclick='nextLinkIndex()'>" + nextLabel + "</a>");
	}
		
	strIndices += "<BR/>";
	strIndices += "<BR/>";
	
	document.getElementById("indexText").innerHTML = strIndices;
}
function setlink( url )
{
	window.opener.location = url;
	setTimeout("form_value_feedback()", 500);
}	
function form_value_feedback ()
{
	window.opener.document.searchform.word.value = resultDoc.strOrgInputText;
}
// JSONファイルをダイナミックにロードする
function loadJSONfile( JSONFile )
{
	var script = document.createElement("script");
	script.charset = "utf-8";
	script.src = JSONFile;
	var node = document.body.appendChild(script);
}
// 検索結果をクリアする
function clearResult()
{
    for(var i = 1 ; i <= IndexLink.nResultPerPage; ++i )
    {
		var strSearchResult = "SearchResult"+i;
		document.getElementById( strSearchResult ).innerHTML = "";
    }
}
// 検索結果をプリントする
function printResult( strSearchResult, strTitle, strLinkTarget, strLink, strContent )
{
	var str = '<dl>';
	str += ( '<dt>' + strTitle + '</dt>' );
	str += ( '<dd class="title"><a href="javascript:setlink(\'../contents/' + strLinkTarget + '/func.html\');" target="_parent">' + strLink + '</a></dd>');
	if( resultDoc.bQuote )
	{
		str += ( '<dd class="text" id="dd' + strSearchResult +  '" >' + strContent + '</dd>' );
	}
	else
	{
		str += ( '<dd style="display:none;" "class="text" id="dd' + strSearchResult +  '" >' + strContent + '</dd>' );
	}
	str += ( '</dl>' );
	
	document.getElementById( strSearchResult ).innerHTML = str;
}
// 検索後を分解し、インデックス検索にヒットした場合には、AND配列にセット、
// ヒットしなかった場合には、キーワードリストから全語、部分検索を実行して、
// OR配列を作成。スペースで区切られた語は、AND検索を行う。
// また、ダブルクオートで区切られた語は、１つの検索語と見なす。
function searchOperation()
{
	var	b_flag = false;
	//alert( "searchOperation()" );
	//var resultDoc.strInputText = document.getElementById( "textInput" ).value;
	// テキストボックスに書き戻すために、オリジナルのデータを保持しておく
	// 2008/06/06　A.Murata 新規作成
	resultDoc.strOrgInputText =  window.opener.document.searchform.word.value;
	resultDoc.strInputText  = resultDoc.strOrgInputText;

	// 2008/06/05　A.Murata 新規作成
	if( resultDoc.strInputText.length <= 0 )
	{
		this.close();
	}

	// もし、実体参照文字(&amp;等)が含まれていれば、&を実体参照文字に変換する
	// 実体参照文字は検索してもヒットしないが、検索結果ウィンドウに入力された実体参照文字を表示するため
	// 2008/05/27　A.Murata 新規作成
	if( IsContainsHtmlChar(resultDoc.strInputText ) == true )
	{
		resultDoc.strInputText = ConvertToAmpChar(resultDoc.strInputText);
	}
	
	if( b_flag == true )
	{
		// トークンに分解
    	resultDoc.searchWord =  ToToken( resultDoc.strOrgInputText );
    	resultDoc.searchWordOrg = ToToken( resultDoc.strOrgInputText );// 2008/06/17　A.Murata 新規作成
    }
    else
    {
    	resultDoc.searchWord = new Array();
    	resultDoc.searchWord[0] = resultDoc.strOrgInputText;
    	resultDoc.searchWordOrg[0] = resultDoc.strOrgInputText;// 2008/06/17　A.Murata 新規作成
    }

    resultDoc.nMaxSearchWord = resultDoc.searchWord.length;
    // 結果配列の初期化
  	var andArray = new Array();
	var orArray = new Array();

	for( var k = 0; k < nArrayLength; ++k )
	{
		andArray[k] = 0xFFFFFFFF;
	}

	// テキストボックスに入力された文字列を連想配列から探して、
	// 見つかれば、ビット配列をANDして行く。
	var nAndCount = 0;
    for( var i = 0; i < resultDoc.nMaxSearchWord; ++i )
    {
    	// 実体参照文字と小文字に変換
    	// 2008/05/26　A.Murata 変更
    	//resultDoc.searchWord[i]  = ConvertToLower( ConvertToHtmlChar( resultDoc.searchWord[i] ) );
    	resultDoc.searchWord[i]  = ConvertToLower( resultDoc.searchWord[i] );
    		
        var uintArray = keyIndex[resultDoc.searchWord[i]];
        resultDoc.wordSearchResult[i] = false;
        // キーが完全一致した場合
        if( uintArray )
        {
    		resultDoc.wordSearchResult[i] = true;
            var strDecode = Decode(uintArray);
            uintArray = StringToUint(strDecode);
            AND( uintArray, andArray );
            ++nAndCount;
       }
       else
       {
		    // 連想配列を部分検索する
			var nOrCount = 0;
			for( var k = 0; k < nArrayLength; ++k )
			{
				orArray[k] = 0x0;
			}
			for( var key in keyIndex )
			{
				var nPos = key.indexOf(resultDoc.searchWord[i]);
				
				// 部分一致した場合にはORをする
				if( nPos >= 0 )
				{
					var uintArray = keyIndex[key];
					var strDecode = Decode(uintArray);
					uintArray = StringToUint(strDecode);
					OR( uintArray, orArray );
					++nOrCount;
				}
			}
       	   
       	   if( nOrCount == 0 )
       	   {
       	   	   // 見つからなかった場合
	    	   resultDoc.wordSearchResult[i] = false;
	    	   //( resultDoc.searchWord[i] + "は、見つかりません" + "<BR/>" );         
	       }
	       else 
	       {
	       	   resultDoc.wordSearchResult[i] = true;
	       	   // ANDを取る
       	    	AND( orArray, andArray );
       	        ++nAndCount;	
	       }
       } 
    } 

	resultDoc.nHitCount = 0;
	// AND計算が行われた場合にヒット数をカウントする。
	if( nAndCount > 0 )
	{
    	var nCount = 0;	
	    for (var i = 0; i < nArrayLength; ++i)
	    {
	        for (var j = 0; j < 32; ++j)
	        {
	            if ( (andArray[i] & (0x1 << j) ) != 0 )
	            {
	                resultDoc.contentIndexArray[resultDoc.nHitCount] = nCount;
	                resultDoc.nHitCount++;
	            }
	       		++nCount;     
	        }
	    }
    }

    return resultDoc.nHitCount;
}
// 2008/06/03　A.Murata 新規作成
function SafariCheck()
{
	var strSafari = "Safari";
	var strAppVersion = navigator.appVersion;
	var nSafari = strAppVersion.indexOf(strSafari);
	var fVersion = ( nSafari >= 0 )? parseFloat(strAppVersion.substring(nSafari+(strSafari.length)+1, strAppVersion.length )):0.0;
	var nMac = navigator.appVersion.indexOf("Mac");
	
	if( nSafari != -1 && nMac != -1 )
	{
		return 1;
	}
	return 0;
}
