﻿/////////////////////////////////////////
// Program:
// runlength.js
// Description:
// インデックス検索を行うためのユーティリティ
// Date: 2008/05/16
// 2008/05/19　全角の＆を入力しても実体参照文字に変換されないバグを修正
// 2008/05/20 ダブルクオートて区切るため、ダブルクオートをHTMLの実体参照に変換しないように修正
// 2008/05/23 コロンの全角(：)を半角(:)に直す部分を半角(,)にしていました。修正しました。
// 2008/05/27 z2hHashtable配列に、＜＞”全角スペース＝が抜けていた。
// 2008/06/06 Safari2.0で動作するようにConvertToLowerを書き直した。
// 2008/06/09 全角を半角に変換する正規表現配列を作成して、メモリを消費しないように変更した。
// Author: Atsutoshi Murata
// 
/////////////////////////////////////////
// 整数配列のANDを取る
function AND( uintArrayIn, uintArrayOut )
{
	for( var i = 0, length = uintArrayIn.length; i < length; ++i )
	{
		uintArrayOut[i] &= uintArrayIn[i];
	}
}
// 整数配列のORを取る
function OR( uintArrayIn, uintArrayOut )
{
	for( var i = 0, length = uintArrayIn.length; i < length; ++i )
	{
		uintArrayOut[i] |= uintArrayIn[i];
	}
}
// 整数値を16進数の文字列に変換する
function UintToString( uintArray )
{
	var strResult = "";
	for( var i = 0, length = uintArray.length; i < length; ++i )
	{
		var strUint = uintArray[i].toString(16);
	    var strFormat = "00000000".substring( 0, 8 - strUint.length) + strUint;
	    strResult += strFormat;
	}
	return strResult;
}
// 16進数を整数の配列に変換する
function StringToUint(str)
{
	//substring(文字の位置、文字の終了位置)
	var uintArray = new Array();
	for( var i = 0, length = str.length, j = 0; i < length; i += 8, j++ )
	{
		//document.write( i, " : ",  str.substring(i,i+8), "<BR/>");
		uintArray[j] = parseInt( str.substring(i,i+8), 16 );
	}
	return uintArray;
}
// エンコードされたキャラクタ(gからpならtrue)かを調べる
function IsEncodeChar(strText, index)
{
	var nCharCode = strText.charCodeAt(index);
    if ( nCharCode < "g".charCodeAt(0) || nCharCode > "p".charCodeAt(0))
    {
        return false;
    }
    return true;
}
// エンコードされたキャラクタを返す   
function GetEncodeChar(nNumber)
{
    return String.fromCharCode("g".charCodeAt(0) + nNumber);
}
// エンコードされたキャラクタから番号を返す
function GetDecodeNumber( strEncode, index )
{
    return strEncode.charCodeAt(index) - "g".charCodeAt(0);
} 
// 数字を(123 -> hij)エンコードキャラクタに変換する
function EncodeStr(nCount)
{
	// 123を"123"に変換する
	var strCount = nCount.toString(10);
    var strResult = "";
    // "1"->"h", "2"->"i", "3"->"j"にエンコードする。
    for ( var i = 0, length = strCount.length; i < length; ++i )
    {
    	var str = ""+ strCount.charAt(i);
        strResult += GetEncodeChar( parseInt( str ) );
    }
    return strResult;
}
//ビット列をANDやORをとった後に、JavaScriptのプリント動作がおかしくなるため、
// ビット列を2進数の文字列化して整数に再変換する
function ReconstructionBitField( uint )
{
	var strBin = "";
	for( var i = 0; i < 32; ++i )
	{	
		strBin += (uint & (0x1 << (31-i)) )? "1":"0";	
	} 
	return parseInt(strBin,2);
}
// 16進数の文字列をランレングスでエンコードする
// 0が連続する場合に、gからpまでのコードに置き換える
// 0 -> g
// 1 -> h
// 2 -> i
// 3 -> j
// 4 -> k
// 5 -> l
// 6 -> m
// 7 -> n
// 8 -> o
// 9 -> p
function Encode(strText)
{
	var nLength = strText.length;
	var strResult = "";
	var i = 0;
	var nZeroCount = 0;
	var bZeroFound = false;
	
    while (i < nLength)
    {
    	// もし０があったらカウントする
        if (strText.charAt(i) == '0')
        {
            if (bZeroFound == false)
            {
                nZeroCount = 0;
                bZeroFound = true;
            }
            ++nZeroCount;
        }
        else
        {
        	// ０が見つかっていた場合には、０をランレングスで圧縮した文字列にする
            if (bZeroFound == true)
            {
                strResult += EncodeStr(nZeroCount);
            }
            strResult += strText.charAt(i);
            bZeroFound = false; 
        }
        ++i;
    }

    if (bZeroFound == true)
    {
        sbResult += EncodeStr(nZeroCount);
    }
    return strResult;
}
// エンコードされた文字列を0
function GetZeroString(strEncode)
{
	// "hij" を "123" に変換する
	var strNum = "";
	for ( var i = 0, length = strEncode.length; i < length;  ++i)
	{
		var n = GetDecodeNumber( strEncode,i );
		strNum += n;
	}
	// "123" を 123に変換する
	var nZeroCount = parseInt(strNum);
	// 123個の0の配列を返す
	var strArray = "";
	for (var i = 0; i < nZeroCount; ++i)
	{
		strArray += "0";
	}
	return strArray;KOPI
}
// エンコードされた文字列を16進数に戻す
function Decode(strText)
{
    var strResut = "";
    var nLength = strText.length;
    var i = 0;
    var strEncStr = "";

    while (i < nLength)
    {
        if (IsEncodeChar(strText,i) == true)
        {
            strEncStr += strText.charAt(i);
        }
        else
        {
            if( strEncStr.length > 0 )
            {
                strResut += GetZeroString(strEncStr);
                strEncStr= "";
            }
            
            strResut += strText.charAt(i);
        }
        ++i;
    }
    if (strEncStr.length > 0 )
    {
       strResut += GetZeroString(strEncStr);
    }
    
    return strResut;
}
// Safari2.0では、2バイト文字を使った文字列の検索や置き換えが上手く動作しない。
// [＆]と1文字なら動作するので、一文字ずつ判定して文字列の置換を行う様に修正
// 2008/06/06　A.Murata 新規作成
// 正規表現の配列
var regexZ2HArray = null;

function ConvertToLower( text )
{
	// 正規表現の配列を最初に作成しておく
	// 2008/06/09　A.Murata 新規作成
	if( regexZ2HArray == null )
	{
		regexZ2HArray = new Array();
		var nIndex = 0;
		for( var key in z2hHashtable )
	   	{
			regexZ2HArray[nIndex++] = new RegExp(key, "g");
		}
	}
	
	// 置き換え文字列文字列を一文字ずつ調べる
	var nIndex = 0;
	for( var key in z2hHashtable )
   	{
   		// 2008/06/09　A.Murata 変更
		//var regex = new RegExp(key, "g");
		var result = text.match(regexZ2HArray[nIndex++]);
		
		// もし全角の英数字一致した文字列があるのなら、英数字に変換する
		if( result != null )
		{
			for( var i = 0, length = result.length; i < length; ++i )
			{
				// 連想配列を参照して、文字列を英数字に置き換える
				text = text.replace( result[i], z2hHashtable[result[i]] );
			}
		}
	}
	// もし大文字にマッチするのなら、小文字に変換する
	if( text.match( /[A-Z]/g ) != null )
	{	
		text = text.toLowerCase();
	}
	
	return text;
}
function ConvertToAmpChar(text)
{
	var strResult = "";
	// 連想配列を参照して、文字列を英数字に置き換える
	// 小文字化したテキストを探して、小文字化したキーワードが一致する位置を調べる
	var pos1 = pos2 = 0;
	while( ( pos2 = text.indexOf( '&', pos1 ) ) >= 0 )
	{
		// 一致した場合には、元のテキストを連結してつないで行く
		strResult += text.substr( pos1, pos2 - pos1 ) + "&amp;";
		pos1 = pos2 + 1;
	}
	strResult += text.substr( pos1 );	

	return strResult;
}
// 2008/05/27　A.Murata 新規作成
function IsContainsHtmlChar(strText)
{
	for( var i = 0, length = htmlCharEntityArray.length; i < length; ++i )
	{
		// 連想配列を参照して、文字列を英数字に置き換える
		if( htmlCharEntityArray[i].length > strText.length )
		{
			var nPos =  htmlCharEntityArray[i].indexOf(strText);
			if( nPos >= 0 )
			{
				return true;
			}
		}
		else
		{
			var nPos =  strText.indexOf( htmlCharEntityArray[i] );
			if( nPos >= 0 )
			{
				return true;
			}
		}
	}
	return false;
}
// テキスト入力をトークンに分解する
// "と"で囲まれた部分を１つの検索語とする
// 2008/05/19　A.Murata 変更
// 2008/05/16　A.Murata 変更
function ToToken( strWords )
{
	var tokens = strWords.split(/　| |\t/);	
	var startPos = -1;
	var strWork;
	// 削除することを想定して、最後の単語から調べる
	for( var i = tokens.length-1; i >= 0; --i )
	{
		// 長さが０のトークンを削除
		if( tokens[i].length <= 0 )
		{
			tokens.splice( i, 1);
			continue;
		}
		
		// 最初と最後のキャラクタが"か”なら、文字列をスペースで連結する
		var lastChar = tokens[i].charAt(tokens[i].length-1);
		var	firstChar = tokens[i].charAt(0);
		
		// ”が最後についている単語が現れた場合
		if( lastChar == '\"' || lastChar == '”' )
		{
			// もし最初にもついている場合には、単に""でくくっただけなので、""を取る
			// 2008/05/19　A.Murata 変更
			if( firstChar == '\"' || firstChar == '”' )
			{
				//tokens[i] = tokens[i].substring(1,tokens[i].length-1);
			}
			else
			{
				strWork = tokens[i].substring(0,tokens[i].length-1);
				startPos = i;// トークンの開始位置を保存
			}
		}
		else if( startPos > 0 )// "の内部の場合
		{
			// ”が最初についている単語が現れた場合
		   if( firstChar == '\"' || firstChar == '”' )
		   {
		   		// トークンに連結する
		   		tokens[i] = tokens[i].substring(1, tokens[i].length) + " " + strWork;
		   		// 最後に”が出現したトークンから、１つ前のトークンまでを削除する
		   		tokens.splice( i+1, startPos-i);
		   		startPos = -1;// リセット
		   }
		   else
		   {
		   		//"と"の内部の場合には、単語をスペースで連結して行く
		   		strWork = tokens[i] + " " + strWork;
		   }
		}
	}
	return tokens;
}
// テキストのハイライト用のタグをつける
// ビットフィールドを作成し、キーワードが
// テキストにマッチする位置のビットをオンにして行く
// 位置が重複するキーワードのタグ付け対策
// 2008/06/04　A.Murata 新規作成
function highlightText(strTextOrg, strText, strKeywords)
{
	// テキストの文字列の長さのビット数の配列を作成する
	var nBitArrayLength = Math.floor(strText.length/32 )+ 1;
	// ビット配列を作成
	var bitArray = new Array(nBitArrayLength);
	
	for( var i = 0; i < nBitArrayLength; ++i )
	{
		bitArray[i] = 0x0;
	}
	// キーワードの数分、テキストに一致する位置のビットを１にする
	for( var i = 0, length = strKeywords.length; i < length; ++i )
	{
		var strKeyword = strKeywords[i];
		var nKeywordLength = strKeyword.length;
		
		var pos1 = pos2 = 0;
		while( ( pos2 = strText.indexOf( strKeyword, pos1 ) ) >= 0 )
		{
			pos1 = pos2 + nKeywordLength;
			for( var j = pos2; j < pos1; ++j )
			{
				// di:ビット配列のインデックス
				// re:ビット配列内のビット位置
				var di = Math.floor(j / 32);
				var re = Math.floor(j % 32);
				bitArray[di] |= (0x1  << (31-re));
			}
		}
	}
	
	// 見つかったビット位置にタグを挿入する
	var bStartFlag = 0;
	var strResult = "";
	var pos1 = pos2 = 0;
	for( var i = 0, length = strText.length; i < length; ++i )
	{
		var di = Math.floor(i / 32);
		var re = Math.floor(i % 32);

		var bitTest = (bitArray[di] & (0x1  << (31-re)))? 1: 0;

		//　ビットがあった場合に
		if(bitTest  )
		{
			if( !bStartFlag )
			{
				strResult += "<span style='background-color:#87cefa'>";
				bStartFlag = 1;
			}
		}
		else
		{
			if( bStartFlag )
			{
				strResult += "</span>";
				bStartFlag = 0;
			}
		}
		if(  htmlCharEntity[strTextOrg.charAt(i)] )
		{
			strResult += htmlCharEntity[strTextOrg.charAt(i)];
		}
		else
		{
			strResult += strTextOrg.charAt(i);
		}
	}
	return strResult;
}
// テキストボックス中の文字列を実体参照文字に変換する(&以外)
// 2008/06/17　A.Murata 新規作成
function ToHtmlEntityChar(strText)
{
	var strResult = "";
	for( var i = 0, length = strText.length; i < length; ++i )
	{	
		if( strText.charAt(i) != '&' && htmlCharEntity[strText.charAt(i)] )
		{
			strResult += htmlCharEntity[strText.charAt(i)];
		}
		else
		{
			strResult += strText.charAt(i);
		}
	}
	return strResult;
}
